orca r3901 - in branches/gnome-2-22: . src/orca



Author: joanied
Date: Sun May 18 03:30:02 2008
New Revision: 3901
URL: http://svn.gnome.org/viewvc/orca?rev=3901&view=rev

Log:
* src/orca/Gecko.py:
  Fix for bug #533125 - Orca does not speak Search textbox in
  Firefox Download Manager if it is empty.



Modified:
   branches/gnome-2-22/ChangeLog
   branches/gnome-2-22/src/orca/Gecko.py

Modified: branches/gnome-2-22/src/orca/Gecko.py
==============================================================================
--- branches/gnome-2-22/src/orca/Gecko.py	(original)
+++ branches/gnome-2-22/src/orca/Gecko.py	Sun May 18 03:30:02 2008
@@ -3894,7 +3894,8 @@
 
         # The search entries in Firefox's and Thunderbird's top toolbars
         # contain text which functions as the label (Yahoo, Entire Message)
         # and which gets deleted just prior to the entry gaining focus.  If
         # we pass that event on to the default script, it will set the
         # entry to the locus of focus silently and then the focus event
         # will not cause the entry to be spoken.  In addition, if the
@@ -3904,6 +3905,9 @@
         #
         if event.source and orca_state.locusOfFocus \
            and not self.isSameObject(event.source, orca_state.locusOfFocus):
+            if event.source.parent.getRole() == pyatspi.ROLE_FRAME:
+                return
+
             toolbar = self.getAncestor(event.source,
                                        [pyatspi.ROLE_TOOL_BAR],
                                        [pyatspi.ROLE_DOCUMENT_FRAME])
@@ -3894,7 +3894,8 @@
         # The search entries in Firefox's and Thunderbird's top toolbars
         # contain text which functions as the label (Yahoo, Entire Message)
-        # and which gets deleted just prior to the entry gaining focus.  If
+        # and which gets deleted just prior to the entry gaining focus.
+        # This is also true of the search entry in the Downloads frame. If
         # we pass that event on to the default script, it will set the
         # entry to the locus of focus silently and then the focus event



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]